routes

package
v0.0.0-...-d0503b8 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 9, 2022 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CreateGroup

func CreateGroup(ctx *gin.Context)

Create new group , returns new group: CREATE/POST

func CreateUser

func CreateUser(ctx *gin.Context)

Add a user into the database table : POST

func DeleteGroup

func DeleteGroup(ctx *gin.Context)

Delete group, returns successful delete message

func DeleteUser

func DeleteUser(ctx *gin.Context)

Delete user from the database : DELETE

func GetGroupByID

func GetGroupByID(ctx *gin.Context)

Return a single group using group id : READ

func GetGroups

func GetGroups(ctx *gin.Context)

Returns all groups to the caller : READ

func GetUserByID

func GetUserByID(ctx *gin.Context)

Get a single user with a given user id : READ

func GetUsers

func GetUsers(ctx *gin.Context)

Returns all users to the caller : READ

func RouteHandler

func RouteHandler()

Initializes route handler, and the server on port 8000

func UpdateGroup

func UpdateGroup(ctx *gin.Context)

Update group data , returns updated group: UPDATE/PUT

func UpdateUser

func UpdateUser(ctx *gin.Context)

Updte user data : UPDATE

Types

This section is empty.

Jump to